
#! /bin/sh
#
# This install script will be invoked by extract_unbundled.
# Media:
# 	local floppy diskette in bar format
#
# Extract_unbundled invokes us with the following arguments:
#	-dDEVICE -rREMOTE_HOST -DEFAULT

PROD="Uagent v3.1 for Cheyenne ARCserve"
DEF_INSTALL_PATH="/usr"
INSTALL_DIR=""

PATH=/usr/ucb:/bin:/usr/bin:/etc:/usr/etc
export PATH
LOGFILE="/tmp/log"
MYNAME="$0"

#
# Utilities
#

MKDIR="mkdir -p"
CD="cd"
BAR="bar"
MV="mv -f"

PSFLAG="-ax"
PSCUT="-c1-5"

check_uagent()
{
  pid=`ps $PSFLAG | grep uagentd | grep -v "grep uagentd" | cut $PSCUT` 
}

#
# usage -- display error message, usage info and exit
#
usage () {
	if [ "$1" ] 
	then
		echo "$MYNAME: $1"
	fi
	echo "Usage:  $MYNAME -dDEVICE [ -rREMOTE_HOST ] [ -DEFAULT ]"
	exit 1
}

#
# read_log -- log stdin
#
read_log () {
	read $1
	eval echo "\$$1" >> $LOGFILE
}

echo_log() {
    echo "$@" >> $LOGFILE
    echo "$@"
}

#
# yorn - get y or n from user
# Usage: yorn Arg#1 Arg#2 Arg#3
#     Arg #1 = result
#     Arg #2 = output message
#     Arg #3 = default response (optional)
#
yorn () {

    ANSWER="-1"
    until test $ANSWER = Y -o $ANSWER = y -o $ANSWER = N -o $ANSWER = n
    do         
        echo_log -n "$2"
        if [ "$3" != "" ]
        then
           echo_log -n " [$3] "
        fi

        read_log ANSWER
		if [ "$ANSWER" = "" ]
		then
                ANSWER="-1"
		fi

        if [ "$ANSWER" = "-1" -a "$3" != "" ] 
        then
                ANSWER="$3"
        fi
        echo_log
    done
    eval $1="$ANSWER"
}

#
# Ask - ask the user a question.
# Usage: ask Arg#1 Arg#2 Arg#3
#     Arg #1 = result
#     Arg #2 = output message
#     Arg #3 = default response (optional)
#
ask () {

    ANSWER=""
    while [ "$ANSWER" = "" ]
    do         
        echo_log -n "$2"
        if [ "$3" != "" ]
        then
           echo_log -n " [$3] "
        fi
        read_log ANSWER

        if [ "$ANSWER" = "" -a "$3" != "" ] 
        then
                ANSWER="$3"
        fi
        echo_log
    done
    eval $1="$ANSWER"
}

#
# ErrorExit -- display error message and exit
#
ErrorExit() {
	if [ "$1" ] 
	then
		echo_log "$1"
	else
		echo_log "Fatal error occurred..."
	fi	
        echo_log "$PROD Installation aborted..."
	exit 1
}
#
#              >>>> Here beginith the real work <<<<
#

#
#   Make sure is root user
#

USER=`whoami`
if [ "$USER" != "root" ]
then
    ErrorExit "Only root can run installation script"
fi

BIN=/usr/bin
OPTIONS="xvfpZT"
#OPTIONS="xvf"
pid=

ask INSTALL_DIR "Where should Uagent be installed? " $DEF_INSTALL_PATH
#set -x
#extracts the package

check_uagent
if [ "$pid" != "" ]
then
  /usr/5bin/echo "\nShutting down UAGENT process...\c"
  kill -15 $pid > /dev/null 2>&1
  /usr/5bin/echo "Down\n"
  sleep 3
fi

echo_log "Extracting package ..."
echo_log

if [ ! -d $INSTALL_DIR/uagent ]      # if directory not exists, make it
then
	$MKDIR $INSTALL_DIR/uagent
fi
chmod 755 $INSTALL_DIR/uagent
chown bin $INSTALL_DIR/uagent
chgrp bin $INSTALL_DIR/uagent

DEVPATH=`pwd`/uag.31
$CD $INSTALL_DIR/uagent
$BAR ${OPTIONS} ${DEVPATH}
#chmod 755 uagentd
#chown bin uagentd
#chgrp bin uagentd
#chmod 755 uagent
#chown bin uagent
#chgrp bin uagent

#
# modify the path for 'uagentd' in script 'uagent'
#
sed -e /\$UAGBIN/s]]$INSTALL_DIR]g $INSTALL_DIR/uagent/uagent > /tmp/tmp.uagsh
mv /tmp/tmp.uagsh $INSTALL_DIR/uagent/uagent
chmod 755 $INSTALL_DIR/uagent/uagent
chown bin $INSTALL_DIR/uagent/uagent
chgrp bin $INSTALL_DIR/uagent/uagent

#
# create symbolic link to uagent command script
#
rm -f $BIN/uagent
echo_log "ln -s $INSTALL_DIR/uagent/uagent $BIN/uagent"
ln -s $INSTALL_DIR/uagent/uagent $BIN/uagent
chown bin $BIN/uagent
chgrp bin $BIN/uagent

#
# create a dummy uag.cntl file
#
touch uag.cntl
chmod 666 uag.cntl
chown bin uag.cntl
chgrp bin uag.cntl

echo_log
echo_log "Installation complete."
